@@ -50,11 +50,12 @@ class JWTAuthenticate:
     def __init__(self,pub_key,skip_paths:list):
         self.public_key = pub_key
         self.skip_paths = skip_paths
-    async def authenticate_middleware(self,request: Request, call_next):
+    async def authenticate_middleware(self,request: Request,request_body, call_next):
         try:
             start_time = time.time()
             current_path =  request.scope["path"]
-            # print("current path: %s" % current_path)
+
+            print("current path: %s" % current_path)
             for path in self.skip_paths:
                 if current_path.endswith(path):
                     return await call_next(request)
@@ -64,7 +65,7 @@ class JWTAuthenticate:
             bearer,token = credentials.split()  
             if bearer != "Bearer":
                 return JSONResponse(status_code=status.HTTP_401_UNAUTHORIZED, content={"message": "Unauthorized"})
-            auth = Authenticator(self.public_key,token)
+            auth = Authenticator(self.public_key,token,request_body)
             if not auth.is_authenticated():
                 return JSONResponse(status_code=status.HTTP_401_UNAUTHORIZED, content={"message": "Unauthorized"})
             response = await call_next(request)
